@@ -6,21 +6,34 @@
 // see file COPYING or www.gnu.org for details
 
 
+#ifdef HAVE_SYSTEM_WEED
+#include "weed/weed.h"
+#include "weed/weed-palettes.h"
+#include "weed/weed-effects.h"
+#include "weed/weed-plugin.h"
+#else
 #include "../../libweed/weed.h"
+#include "../../libweed/weed-palettes.h"
 #include "../../libweed/weed-effects.h"
 #include "../../libweed/weed-plugin.h"
+#endif
 
 ///////////////////////////////////////////////////////////////////
 
-static int num_versions=1; // number of different weed api versions supported
-static int api_versions[]={100}; // array of weed api versions supported in plugin, in order of preference (most preferred first)
+static int num_versions=2; // number of different weed api versions supported
+static int api_versions[]={131,100}; // array of weed api versions supported in plugin, in order of preference (most preferred first)
 
 static int package_version=1; // version of this package
 
 //////////////////////////////////////////////////////////////////
 
+#ifdef HAVE_SYSTEM_WEED
+#include "weed/weed-utils.h" // optional
+#include "weed/weed-plugin-utils.h" // optional
+#else
 #include "../../libweed/weed-utils.h" // optional
 #include "../../libweed/weed-plugin-utils.h" // optional
+#endif
 
 /////////////////////////////////////////////////////////////
 
