@@ -1,6 +1,6 @@
 // callbacks.h
 // LiVES
-// (c) G. Finch <salsaman@xs4all.nl> 2003 - 2009
+// (c) G. Finch <salsaman@xs4all.nl> 2003 - 2010
 // Released under the GPL 3 or later
 // see file ../COPYING for licensing details
 
@@ -32,10 +32,6 @@ void
 on_stop_clicked                         (GtkMenuItem     *menuitem,
                                          gpointer         user_data);
 
-void
-on_save_activate                      (GtkMenuItem     *menuitem,
-				       gpointer         user_data);
-
 void
 on_save_selection_activate            (GtkMenuItem     *menuitem,
 				       gpointer         user_data);
@@ -145,12 +141,7 @@ on_rev_clipboard_activate              (GtkMenuItem     *menuitem,
                                         gpointer         user_data);
 
 void 
-on_audp_entry_changed (GtkWidget *vidp_entry, gpointer);
-
-
-void 
-on_encoder_entry_changed                 (GtkEntry *encoder_entry, 
-					  gpointer ptr);
+on_encoder_entry_changed(GtkComboBox *combo, gpointer ptr);
 
 void 
 on_vid_playback_plugin_changed (GtkEntry *vpp_entry, gpointer user_data);
@@ -209,14 +200,6 @@ void
 on_location_select                   (GtkButton       *button,
 				      gpointer         user_data);
 
-void
-on_locbw_toggled                (GtkToggleButton *togglebutton,
-				 gpointer         user_data);
-
-void
-on_opendeint_toggled                (GtkToggleButton *togglebutton,
-				 gpointer         user_data);
-
 void
 on_autoreload_toggled                (GtkToggleButton *togglebutton,
 				 gpointer         user_data);
@@ -294,11 +277,6 @@ void
 on_mute_activate                (GtkMenuItem     *menuitem,
 				 gpointer         user_data);
 
-void
-on_save_with_sound_activate                (GtkMenuItem     *menuitem,
-				 gpointer         user_data);
-
-
 void
 on_info_ok_button_clicked            (GtkButton       *button,
 				      gpointer         user_data);
@@ -340,6 +318,13 @@ void
 on_load_audio_activate                  (GtkMenuItem     *menuitem,
                                         gpointer         user_data);
 
+void on_load_subs_activate (GtkMenuItem *menuitem, gpointer user_data);
+
+void on_save_subs_activate (GtkMenuItem *menuitem, gpointer entry_widget);
+
+void on_erase_subs_activate (GtkMenuItem *menuitem, gpointer user_data);
+
+
 void
 on_xmms_play_audio_activate                  (GtkMenuItem     *menuitem,
 					      gpointer         user_data);
@@ -353,10 +338,6 @@ on_xmms_stop_audio_activate                (GtkMenuItem     *menuitem,
 					    gpointer         user_data);
 
 
-void
-on_insert_after_toggled                (GtkToggleButton *togglebutton,
-                                        gpointer         user_data);
-
 void 
 on_insfitaudio_toggled                (GtkToggleButton *togglebutton,
 				       gpointer         user_data);
@@ -390,10 +371,6 @@ void
 on_spin_end_value_changed           (GtkSpinButton   *spinbutton,
 				       gpointer         user_data);
 
-void
-on_boolean_toggled        (GtkToggleButton *togglebutton,
-			    gpointer         user_data);
-
 gint
 expose_vid_event (GtkWidget *widget, GdkEventExpose *event);
 
@@ -528,7 +505,6 @@ on_record_perf_activate                      (GtkMenuItem     *menuitem,
 
 gboolean record_toggle_callback (GtkAccelGroup *group, GObject *obj, guint keyval, GdkModifierType mod, gpointer user_data);
 
-gboolean dirchange_callback (GtkAccelGroup *, GObject *, guint, GdkModifierType, gpointer user_data); // defined as extern in dialogs.c
 
 gboolean fps_reset_callback (GtkAccelGroup *, GObject *, guint, GdkModifierType, gpointer user_data);
 
@@ -572,8 +548,7 @@ on_filesel_complex_ok_clicked                      (GtkButton *button,
 						   GtkEntry *entry);
 
 void 
-on_encoder_ofmt_changed                          (GtkEntry *entry, 
-						  gpointer user_data);
+on_encoder_ofmt_changed(GtkComboBox *combo, gpointer user_data);
 
 void
 on_ok_export_audio_clicked                      (GtkButton *button,
@@ -629,10 +604,6 @@ void
 on_resample_vid_ok                  (GtkButton       *button,
 				  GtkEntry         *entry);
 
-void
-on_ccpd_sound_activate                (GtkMenuItem     *menuitem,
-				       gpointer         user_data);
-
 void
 on_trim_audio_activate (GtkMenuItem     *menuitem,
 			gpointer         user_data);
@@ -675,6 +646,9 @@ void
 on_showfct_activate               (GtkMenuItem     *menuitem,
 				   gpointer         user_data);
 
+void on_boolean_toggled  (GtkMenuItem     *menuitem,
+			  gpointer         user_data);
+
 void
 on_show_messages_activate            (GtkMenuItem     *menuitem,
 				      gpointer         user_data);
@@ -733,6 +707,8 @@ gboolean storeclip_callback (GtkAccelGroup *, GObject *, guint, GdkModifierType,
 
 gboolean nervous_callback (GtkAccelGroup *, GObject *, guint, GdkModifierType, gpointer user_data);
 
+gboolean show_sync_callback (GtkAccelGroup *group, GObject *obj, guint keyval, GdkModifierType mod, gpointer clip_number);
+
 void on_save_set_activate (GtkMenuItem *, gpointer user_data);
 
 void on_save_set_ok (void);
@@ -792,4 +768,6 @@ void on_lerrors_close_clicked (GtkButton *, gpointer);
 void on_lerrors_clear_clicked (GtkButton *, gpointer);
 void on_lerrors_delete_clicked (GtkButton *, gpointer);
 
-void on_init_aplayer_toggled (GtkToggleButton *, gpointer new_player);
+void drag_from_outside(GtkWidget *widget, GdkDragContext *dcon, gint x, gint y, 
+		       GtkSelectionData *data, guint info, guint time, gpointer user_data);
+
